import { Component } from '@angular/core';
import { FormBuilder, FormGroup, Validators, ReactiveFormsModule } from '@angular/forms';
import { ImportService, GeoapifyResponse, GeoapifyFeature } from '../../services/import.service';
import { CommonModule } from '@angular/common';
import { POIService } from '../../services/poi.service';
import { POI } from '../../model/POI';

@Component({
  selector: 'app-import',
  templateUrl: './import.component.html',
  styleUrls: ['./import.component.css'],
  imports: [CommonModule, ReactiveFormsModule]
})
export class ImportComponent {
  importForm: FormGroup;
  isLoading = false;
  data: GeoapifyResponse | null = null;
  fieldMappings: { [key: string]: string } = {};
  availableFields: string[] = [];
  targetFields = [
    'title',
    'description',
    'complete_address',
    'latitude',
    'longitude'
  ];

  constructor(
    private fb: FormBuilder,
    private importService: ImportService,
    private poiService: POIService
  ) {
    this.importForm = this.fb.group({
      apiUrl: ['', [Validators.required, Validators.pattern('^https?://.+')]]
    });
  }

  onSubmit(): void {
    if (this.importForm.valid) {
      this.isLoading = true;
      const url = this.importForm.get('apiUrl')?.value;

      this.importService.fetchDataFromUrl(url).subscribe({
        next: (response) => {
          if (this.importService.validateGeoapifyData(response)) {
            this.data = response;
            this.extractAvailableFields(response.features[0]);
            this.initializeFieldMappings();
          } else {
            this.showError('Format de données invalide');
          }
          this.isLoading = false;
        },
        error: (error) => {
          this.showError(error.message);
          this.isLoading = false;
        }
      });
    }
  }

  private extractAvailableFields(feature: GeoapifyFeature): void {
    this.availableFields = Object.keys(feature.properties);
  }

  private initializeFieldMappings(): void {
    this.fieldMappings = {};
    this.targetFields.forEach(field => {
      this.fieldMappings[field] = '';
    });
  }

  updateFieldMapping(targetField: string, sourceField: string): void {
    this.fieldMappings[targetField] = sourceField;
  }

  processImport(): void {
    if (!this.data) return;

    this.isLoading = true;
    let successCount = 0;
    let errorCount = 0;

    // Traiter chaque feature
    this.data.features.forEach(feature => {
      const poi = this.importService.convertToPOI(feature, this.fieldMappings);
      
      this.poiService.addPOI(poi).subscribe({
        next: () => {
          successCount++;
          if (successCount + errorCount === this.data!.features.length) {
            this.showSuccess(`${successCount} POIs importés avec succès`);
            this.isLoading = false;
          }
        },
        error: (error) => {
          console.error('Erreur lors de l\'import du POI:', error);
          errorCount++;
          if (successCount + errorCount === this.data!.features.length) {
            this.showError(`${errorCount} erreurs lors de l'import`);
            this.isLoading = false;
          }
        }
      });
    });
  }

  private showError(message: string): void {
    const notification = document.createElement('div');
    notification.className = 'fixed top-4 right-4 bg-red-500 text-white px-6 py-3 rounded-lg shadow-lg z-50';
    notification.textContent = message;
    document.body.appendChild(notification);

    setTimeout(() => {
      notification.remove();
    }, 5000);
  }

  private showSuccess(message: string): void {
    const notification = document.createElement('div');
    notification.className = 'fixed top-4 right-4 bg-green-500 text-white px-6 py-3 rounded-lg shadow-lg z-50';
    notification.textContent = message;
    document.body.appendChild(notification);

    setTimeout(() => {
      notification.remove();
    }, 5000);
  }
} 